package com.diagbot.facade.data;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.diagbot.dto.AnalyzeRunDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.AHomeOperationDTO;
import com.diagbot.dto.data.AMedicalRecordDTO;
import com.diagbot.dto.data.AMrContentDTO;
import com.diagbot.entity.*;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.enums.data.FamousFamilyEnum;
import com.diagbot.enums.data.NationalityEnum;
import com.diagbot.enums.data.OccupationEnum;
import com.diagbot.enums.data.RelationshipEnum;
import com.diagbot.facade.*;
import com.diagbot.service.impl.MedicalRecordServiceImpl;
import com.diagbot.service.impl.QcAbnormalServiceImpl;
import com.diagbot.util.*;
import com.diagbot.vo.AnalyzeRunVO;
import com.diagbot.vo.data.*;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@Component
public class AMedicalRecordFacade extends MedicalRecordServiceImpl {

    @Autowired
    @Qualifier("medicalRecordServiceImpl")
    private MedicalRecordServiceImpl medicalRecordService;

    @Autowired
    private ModelHospitalFacade modelHospitalFacade;

    @Autowired
    private AMedicalRecordContentFacade aMedicalRecordContentFacade;

    @Autowired
    private BehospitalInfoFacade behospitalInfoFacade;

    @Autowired
    @Qualifier("qcAbnormalServiceImpl")
    private QcAbnormalServiceImpl qcAbnormalService;

    @Autowired
    private QcTypeFacade qcTypeFacade;

    @Autowired
    private ReadProperties readProperties;

    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;

    @Autowired
    private AMedRecordTypeFacade aMedRecordTypeFacade;

    private TZDBConn tzDBConn = new TZDBConn();

    @Autowired
    private SqlProperties sqlProperties;

    @Autowired
    private BasDeptInfoFacade basDeptInfoFacade;

    @Autowired
    private AHomePageFacade aHomePageFacade;

    public static final Map<String, String> CITY_MAP = MapUtil.getMap("cityCode.json");

    /**
     * 终末质控-同步前一天的病历记录
     */
    public void executeMrRecord() {
        //String sql="select * from mr_medicalrecords  where cjcxrq>=dateadd(day,-2,getdate()) and cjcxrq<=getdate()";
        //String sql="select * from mr_medicalrecords  where cjcxrq>=(select CONVERT(varchar,GETDATE()-2,23)) and cjcxrq<(select CONVERT(varchar,GETDATE(),23)) ORDER BY cjcxrq DESC";
        String sql = "select * from ai_v_sendmrrecording where behospitalcode in()";
        List<MedicalRecord> medicalRecordList = tzDBConn.getMedicalRecord(sql);
        execute(medicalRecordList);
    }

    /**
     * 终末质控-通过接口更新病历记录
     *
     * @param list
     * @return
     */
    @Transactional
    public RespDTO<List<AMedicalRecordDTO>> executeMrRecord(List<AMedicalRecordVO> list) {
        try {
            if (list != null && list.size() > 0) {
                //循环验证数据有效性
                for (AMedicalRecordVO aMedicalRecordVO : list) {
                    if ("".equals(aMedicalRecordVO.getRecId())) {
                        return RespDTO.onError("请输入文书序号!");
                    } else if (aMedicalRecordVO.getHospitalId() == null) {
                        return RespDTO.onError("请输入医院编码!");
                    } else if ("".equals(aMedicalRecordVO.getBehospitalCode())) {
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //装载数据
                List<MedicalRecord> medicalRecordList = Lists.newArrayList();
                list.stream().forEach(s -> {
                    MedicalRecord medicalRecord = new MedicalRecord();
                    BeanUtil.copyProperties(s, medicalRecord);
                    medicalRecord.setRecDate(DateUtil.parseDateTime(s.getRecDate()));
                    medicalRecordList.add(medicalRecord);
                });
                execute(medicalRecordList);
                List<AMedicalRecordDTO> medicalRecordDTOList = BeanUtil.listCopyTo(list, AMedicalRecordDTO.class);
                return RespDTO.onSuc(medicalRecordDTOList);
            } else {
                aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息", "", JSON.toJSONString(list), "", "未接收到数据!");
                return RespDTO.onError("未接收到数据!");
            }
        } catch (Exception e) {
            aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息", "", JSON.toJSONString(list), "", e.getMessage());
            return RespDTO.onError(e.getMessage());
        }
    }

    /**
     * 运行质控-通过接口更新病历记录
     *
     * @param aMrContentVO
     * @return
     */
    public RespDTO<Map<String, Object>> executeMrRecordIng(AMrContentVO aMrContentVO) {
        try {
            if (aMrContentVO.getRecords() != null && aMrContentVO.getRecords().size() > 0) {
                AMrContentDTO aMrContentDTO = new AMrContentDTO();
                //循环验证数据有效性
                for (AMedicalRecordVO aMedicalRecordVO : aMrContentVO.getRecords()) {
                    if (aMedicalRecordVO.getRecId() == null || "".equals(aMedicalRecordVO.getRecId())) {
                        return RespDTO.onError("请输入文书序号!");
                    } else if (aMedicalRecordVO.getHospitalId() == null) {
                        return RespDTO.onError("请输入医院编码!");
                    } else if (aMedicalRecordVO.getBehospitalCode() == null || "".equals(aMedicalRecordVO.getBehospitalCode())) {
                        return RespDTO.onError("请输入病人住院编码!");
                    } else if (aMedicalRecordVO.getRecTypeId() == null || "".equals(aMedicalRecordVO.getRecTypeId())) {
                        return RespDTO.onError("请输入病历类别编号!");
                    } else if (aMedicalRecordVO.getRecTitle() == null || "".equals(aMedicalRecordVO.getRecTitle())) {
                        return RespDTO.onError("请输入病历标题!");
                    } else if (aMedicalRecordVO.getContents() == null || aMedicalRecordVO.getContents().size() == 0) {
                        return RespDTO.onError("请输入文书详情!");
                    }
                }
                //更新文书信息
                executeMrRecord(aMrContentVO.getRecords());
                aMrContentVO.getRecords().stream().forEach(s -> {
                    if (StringUtil.isNotEmpty(aMrContentVO.getTranscode())) {
                        String sql = "SELECT CONTENTS FROM AI_V_SENDMRRECORDING WHERE RECID = '" + s.getRecId() + "' AND BEHOSPITALCODE = '" + s.getBehospitalCode() + "'";
                        s.getContents().get(0).setXmlText(tzDBConn.getRecordXml(sql));
                    }
                    aMedicalRecordContentFacade.executeMrRecordContent(s.getContents());
                });
                //评分后返回结构体
                if (aMrContentVO.getRecords().get(0).getRecTypeId().equals("BASY")) {
                    AHomePageIngVO aHomePageIngVO = new AHomePageIngVO();
                    aHomePageIngVO.setHomePages(getHomePageVo(aMrContentVO));
                    aHomePageIngVO.setDockModeType(aMrContentVO.getDockModeType());
                    return aHomePageFacade.executeHomePageIng(aHomePageIngVO);
                } else {
                    return mrIng(aMrContentVO);
                }
            } else {
                aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息", "", JSON.toJSONString(aMrContentVO), "", "未接收到数据!");
                return RespDTO.onError("未接收到数据!");
            }
        } catch (Exception e) {
            aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息", "", JSON.toJSONString(aMrContentVO), "", e.getMessage());
            return RespDTO.onError(e.getMessage());
        }
    }

    /**
     * 评分后返回结构体
     *
     * @param aMrContentVO
     * @return
     */
    private RespDTO<Map<String, Object>> mrIng(AMrContentVO aMrContentVO) {
        try {
            String behospitalCode = aMrContentVO.getRecords().get(0).getBehospitalCode();
            Long hospitalId = aMrContentVO.getRecords().get(0).getHospitalId();
            MedicalRecord medicalRecord = new MedicalRecord();
            BeanUtil.copyProperties(aMrContentVO.getRecords().get(0), medicalRecord);
            Long modeId = initModeId(medicalRecord);
            if (aMrContentVO.getDockModeType().equals("0")) {
                Map<String, Object> map = new HashMap<String, Object>();
                List<AMedicalRecordDTO> medicalRecordDTOList = BeanUtil.listCopyTo(aMrContentVO.getRecords(), AMedicalRecordDTO.class);
                map.put("records", medicalRecordDTOList);
                //aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息",JSON.toJSONString(aMrContentVO),JSON.toJSONString(RespDTO.onSuc(map)),"操作正常!");
                return RespDTO.onSuc("保存成功");
            } else if (aMrContentVO.getDockModeType().equals("1")) {
                if (modeId == null || modeId == 0) {
                    return RespDTO.onSuc("无对应的文书类型");
                }
                //页面模式
                String url = readProperties.getProcessQcUrl() + "?behospitalCode=" + behospitalCode + "&hospitalId=" + hospitalId + "&modeId=" + modeId;
                Map<String, Object> map = new HashMap<String, Object>();
                map.put("url", url);
                //aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息",JSON.toJSONString(aMrContentVO),JSON.toJSONString(RespDTO.onSuc(map)),"操作正常!");
                return RespDTO.onSuc(map);
            } else if (aMrContentVO.getDockModeType().equals("2")) {
                AnalyzeRunVO analyzeRunVO = new AnalyzeRunVO();
                analyzeRunVO.setBehospitalCode(behospitalCode);
                analyzeRunVO.setHospitalId(hospitalId);
                analyzeRunVO.setModeId(modeId);
                AnalyzeRunDTO analyzeRunDTO = behospitalInfoFacade.analyzeRun(analyzeRunVO);
                Map<String, Object> map = new HashMap<String, Object>();
                if (analyzeRunDTO.getMsgDTOList().size() > 0) {
                    map.put("analyze", analyzeRunDTO.getMsgDTOList());
                }
                //aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息",JSON.toJSONString(aMrContentVO),JSON.toJSONString(RespDTO.onSuc(map)),"操作正常!");
                //接口引擎模式
                return RespDTO.onSuc(map);
            } else {
                if (modeId == null || modeId == 0) {
                    return RespDTO.onSuc("无对应的文书类型");
                }
                //页面模式
                String url = readProperties.getProcessQcUrl() + "?behospitalCode=" + behospitalCode + "&hospitalId=" + hospitalId + "&modeId=" + modeId;
                Map<String, Object> map = new HashMap<String, Object>();
                AnalyzeRunVO analyzeRunVO = new AnalyzeRunVO();
                analyzeRunVO.setBehospitalCode(behospitalCode);
                analyzeRunVO.setHospitalId(hospitalId);
                analyzeRunVO.setModeId(modeId);
                AnalyzeRunDTO analyzeRunDTO = behospitalInfoFacade.analyzeRun(analyzeRunVO);

                if (analyzeRunDTO.getMsgDTOList().size() > 0) {
                    map.put("url", url);
                    map.put("analyze", analyzeRunDTO.getMsgDTOList());
                }
                //aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息",JSON.toJSONString(aMrContentVO),JSON.toJSONString(RespDTO.onSuc(map)),"操作正常!");
                return RespDTO.onSuc(map);
            }
        } catch (Exception e) {
            aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息", "", JSON.toJSONString(aMrContentVO), "", e.getMessage());
            if (e.getMessage().contains("该病历无关联的质控条目")) {
                return RespDTO.onSuc(e.getMessage());
            } else {
                return RespDTO.onError(e.getMessage());
            }

        }

    }

    public List<AHomePageVO> getHomePageVo(AMrContentVO aMrContentVO) {
        String behospitalCode = aMrContentVO.getRecords().get(0).getBehospitalCode();
        Long hospitalId = aMrContentVO.getRecords().get(0).getHospitalId();
        String homePageXml = aMrContentVO.getRecords().get(0).getContents().get(0).getXmlText();
        Map<String, Object> ret = YiWuFirstPageRecordXmlUtil.process(homePageXml);
        JSONObject paramsObj = new JSONObject(ret);
        List<AHomePageVO> aHomePageVOList = Lists.newLinkedList();
        AHomePageVO aHomePageVO = new AHomePageVO();
        aHomePageVO.setHomePageId(behospitalCode);
        aHomePageVO.setHospitalId(hospitalId);
        aHomePageVO.setBehospitalCode(behospitalCode);
        //aHomePageVO.setHospitalCode();
        aHomePageVO.setHospitalName(paramsObj.getString("医院代码"));
        //aHomePageVO.setOrgCode();
        aHomePageVO.setPayType(paramsObj.getString("医疗付费方式"));
        aHomePageVO.setHealthCard(paramsObj.getString("居民健康卡号"));
        aHomePageVO.setBehospitalNum(paramsObj.getString("住院次数"));
        aHomePageVO.setFileCode(paramsObj.getString("病案号"));
        aHomePageVO.setName(paramsObj.getString("姓名"));
        aHomePageVO.setSex(paramsObj.getString("性别"));
        if (StringUtil.isNotEmpty(paramsObj.getString("出生日期").replaceAll("[\u4e00-\u9fa5]", "").trim())) {
            aHomePageVO.setBirthday(paramsObj.getString("出生日期").replaceAll("[\u4e00-\u9fa5]", "-"));
        }

        aHomePageVO.setAge(paramsObj.getString("新生儿年龄").replaceAll("[\u4e00-\u9fa5]", ""));
        if (paramsObj.getString("新生儿年龄").contains("天")) {
            aHomePageVO.setAgeUnit("天");
        } else if (paramsObj.getString("新生儿年龄").contains("月")) {
            aHomePageVO.setAgeUnit("月");
        } else {
            aHomePageVO.setAgeUnit("岁");
        }
        aHomePageVO.setNationality(NationalityEnum.getName(paramsObj.getString("国籍")));
        aHomePageVO.setNewbornWeight(paramsObj.getString("新生儿出生体重"));
        //aHomePageVO.setNewbornBehospitalWeight("");
        String[] provinceList = paramsObj.getString("省").split(" ");
        String[] cityList = paramsObj.getString("市").split(" ");
        String[] areaList = paramsObj.getString("县").split(" ");
        if (provinceList.length > 0) {
            if (provinceList[0].length() > 1) {
                aHomePageVO.setBornAddress(CITY_MAP.get(provinceList[0]) == null ? "" : CITY_MAP.get(provinceList[0]));
            }
            if (provinceList[1].length() > 1) {
                aHomePageVO.setResidenceAddress(CITY_MAP.get(provinceList[1]) == null ? "" : CITY_MAP.get(provinceList[1]));
            }
        }
        if (cityList.length > 0) {
            if (cityList[0].length() > 1) {
                aHomePageVO.setBornAddress(aHomePageVO.getBornAddress() + (CITY_MAP.get(cityList[0]) == null ? "" : CITY_MAP.get(cityList[0])));
            }
            if (cityList[1].length() > 1) {
                aHomePageVO.setResidenceAddress(aHomePageVO.getResidenceAddress() + (CITY_MAP.get(cityList[1]) == null ? "" : CITY_MAP.get(cityList[1])));
            }
        }
        if (areaList.length > 0) {
            if (areaList[0].length() > 1) {
                aHomePageVO.setBornAddress(aHomePageVO.getBornAddress() + (CITY_MAP.get(areaList[0]) == null ? "" : CITY_MAP.get(areaList[0])));
            }
            if (areaList[1].length() > 1) {
                aHomePageVO.setResidenceAddress(aHomePageVO.getResidenceAddress() + (CITY_MAP.get(areaList[1]) == null ? "" : CITY_MAP.get(areaList[1])));
            }
        }
        aHomePageVO.setResidenceAddress(aHomePageVO.getResidenceAddress() + paramsObj.getString("户口地址其它"));
        aHomePageVO.setBornPlace(CITY_MAP.get(paramsObj.getString("籍贯_省")) + CITY_MAP.get(paramsObj.getString("籍贯_市")));
        aHomePageVO.setNation(coverValue(paramsObj.getString("民族"),"MZ"));
        aHomePageVO.setIdentityCardNo(paramsObj.getString("身份证号"));
        aHomePageVO.setJobType(OccupationEnum.getName(paramsObj.getString("职业")));
        aHomePageVO.setMarriage(paramsObj.getString("婚姻"));
        aHomePageVO.setCurAddress(CITY_MAP.get(paramsObj.getString("现住址_省")) + CITY_MAP.get(paramsObj.getString("现住址_市")) + CITY_MAP.get(paramsObj.getString("现住址_县")) + paramsObj.getString("现住址其它"));
        aHomePageVO.setCurPhone(paramsObj.getString("现住址电话"));
        aHomePageVO.setCurPostCode(paramsObj.getString("现住址邮编"));
        aHomePageVO.setResidencePostCode(paramsObj.getString("户口地址邮编"));
        aHomePageVO.setWorkAddress(paramsObj.getString("工作单位"));
        aHomePageVO.setWorkPhone(paramsObj.getString("工作单位电话"));
        aHomePageVO.setWorkPostCode(paramsObj.getString("工作单位邮编"));
        aHomePageVO.setContactName(paramsObj.getString("联系人姓名"));
        aHomePageVO.setContactRelation(RelationshipEnum.getName(paramsObj.getString("联系人关系")));
        aHomePageVO.setContactAddress(paramsObj.getString("联系人地址"));
        aHomePageVO.setContactPhone(paramsObj.getString("联系人电话"));
        if (StringUtil.isNotBlank(paramsObj.getString("入院途径"))) { //待定
            aHomePageVO.setBehospitalWay(paramsObj.getString("入院途径").split(" ")[0]);
        }
        if (YWDateUtils.isDate(paramsObj.getString("入院时间"), "yyyy年MM月dd日 HH时mm分") || YWDateUtils.isDate(paramsObj.getString("入院时间"), "yyyy-MM-dd HH:mm:ss")) {
            aHomePageVO.setBehospitalDate(DateUtil.format(YWDateUtils.parseDateTime(paramsObj.getString("入院时间")), DateUtil.DATE_TIME_FORMAT));
        }

        aHomePageVO.setBehospitalDept(coverValue(paramsObj.getString("入院科别"),"KS"));
        aHomePageVO.setBehospitalWard(paramsObj.getString("入院病房"));
        //aHomePageVO.setBehospitalBedId();
        //aHomePageVO.setBehospitalBedCode();
        aHomePageVO.setChangeDept(paramsObj.getString("转科科别"));
        if (YWDateUtils.isDate(paramsObj.getString("出院时间"), "yyyy-MM-dd HH:mm:ss") || YWDateUtils.isDate(paramsObj.getString("出院时间"), "yyyy年MM月dd日 HH时mm分")) {
            aHomePageVO.setLeaveHospitalDate(DateUtil.format(YWDateUtils.parseDateTime(paramsObj.getString("出院时间")), DateUtil.DATE_TIME_FORMAT));
        }
        aHomePageVO.setLeaveHospitalDept(paramsObj.getString("出院科别"));
        aHomePageVO.setLeaveHospitalWard(paramsObj.getString("出院病房"));
        //aHomePageVO.setLeaveHospitalBedId();
        //aHomePageVO.setLeaveHospitalBedCode();
        aHomePageVO.setBehospitalDayNum(paramsObj.getString("实际住院天数"));
        aHomePageVO.setOutpatientEmrDiagnose(paramsObj.getString("门急诊诊断"));
        aHomePageVO.setOutpatientEmrDiagnoseCode(paramsObj.getString("门诊诊断编码"));
        aHomePageVO.setPoisonFactor(paramsObj.getString("损伤中毒因素"));
        aHomePageVO.setPoisonFactorCode(paramsObj.getString("损伤中毒因素编码"));
        aHomePageVO.setPathologyDiagnose(paramsObj.getString("病理诊断"));
        aHomePageVO.setPathologyDiagnoseCode(paramsObj.getString("病理诊断编码"));
        //aHomePageVO.setPathologyDiagnoseId();
        aHomePageVO.setIsMedAllergy(paramsObj.getString("药物过敏"));
        aHomePageVO.setMedAllergyName(paramsObj.getString("过敏药物"));
        aHomePageVO.setAutopsy(paramsObj.getString("死亡患者尸检"));
        aHomePageVO.setBloodType(paramsObj.getString("血型"));
        aHomePageVO.setRh(paramsObj.getString("Rh"));
        aHomePageVO.setDeptDirector(coverValue(paramsObj.getString("科主任"),"ZG"));
        aHomePageVO.setDirectorDoctor(coverValue(paramsObj.getString("主任医师"),"ZG"));
        aHomePageVO.setAttendingDoctor(coverValue(paramsObj.getString("主治医师"),"ZG"));
        aHomePageVO.setBehospitalDoctor(coverValue(paramsObj.getString("住院医师"),"ZG"));
        aHomePageVO.setResponseNurse(coverValue(paramsObj.getString("责任护士"),"ZG"));
        aHomePageVO.setStudyDoctor(coverValue(paramsObj.getString("进修医师"),"ZG"));
        aHomePageVO.setPracticeDoctor(coverValue(paramsObj.getString("实习医师"),"ZG"));
        aHomePageVO.setEncodeMan(coverValue(paramsObj.getString("编码员"),"ZG"));
        aHomePageVO.setHomePageQuality(paramsObj.getString("病案质量"));
        aHomePageVO.setQcDoctor(coverValue(paramsObj.getString("质控医师"),"ZG"));
        aHomePageVO.setQcNurse(coverValue(paramsObj.getString("质控护士"),"ZG"));
        if (YWDateUtils.isDate(paramsObj.getString("质控日期"), "yyyy-MM-dd HH:mm:ss")) {
            aHomePageVO.setQcDate(DateUtil.format(YWDateUtils.parseDateTime(paramsObj.getString("质控日期")), DateUtil.DATE_TIME_FORMAT));
        }
        aHomePageVO.setLeaveHospitalType(paramsObj.getString("离院方式"));
        aHomePageVO.setAcceptOrgCode(paramsObj.getString("接收机构名称"));
        aHomePageVO.setAgainBehospitalPlan(paramsObj.getString("三十一天内再住院计划"));
        aHomePageVO.setAgainBehospitalGoal(paramsObj.getString("再住院目的"));
        aHomePageVO.setTbiBeforeDay(paramsObj.getString("颅脑损伤患者昏迷前天数"));
        aHomePageVO.setTbiBeforeHour(paramsObj.getString("颅脑损伤患者昏迷前小时"));
        aHomePageVO.setTbiBeforeMinute(paramsObj.getString("颅脑损伤患者昏迷前分钟"));
        aHomePageVO.setTbiAfterDay(paramsObj.getString("颅脑损伤患者昏迷后天数"));
        aHomePageVO.setTbiAfterHour(paramsObj.getString("颅脑损伤患者昏迷后小时"));
        aHomePageVO.setTbiAfterMinute(paramsObj.getString("颅脑损伤患者昏迷后分钟"));
        aHomePageVO.setTotalFee(paramsObj.getString("总费用"));
        aHomePageVO.setOwnFee(paramsObj.getString("自付金额"));
        aHomePageVO.setGeneralFee(paramsObj.getString("一般医疗服务费"));
        aHomePageVO.setServiceFee(paramsObj.getString("一般治疗服务费"));
        aHomePageVO.setNurseFee(paramsObj.getString("护理费"));
        aHomePageVO.setOtherFee(paramsObj.getString("其他费用"));
        aHomePageVO.setPathologyFee(paramsObj.getString("病理诊断费"));
        aHomePageVO.setLabFee(paramsObj.getString("实验室诊断费"));
        aHomePageVO.setPacsFee(paramsObj.getString("影像学诊断费"));
        aHomePageVO.setClinicDiagnoseFee(paramsObj.getString("临床诊断项目费"));
        aHomePageVO.setNotOperationFee(paramsObj.getString("非手术治疗项目费"));
        aHomePageVO.setClinicPhysicFee(paramsObj.getString("临床物理治疗费"));
        aHomePageVO.setOperationTreatFee(paramsObj.getString("手术治疗费"));
        aHomePageVO.setAnaesthesiaFee(paramsObj.getString("麻醉费"));
//        aHomePageVO.setOperationFee();
        aHomePageVO.setHealthTypeFee(paramsObj.getString("康复类"));
        aHomePageVO.setChnTreatFee(paramsObj.getString("中医治疗费"));
        aHomePageVO.setWesternMedFee(paramsObj.getString("西药费"));
        aHomePageVO.setAntibiosisFee(paramsObj.getString("抗菌药物费用"));
        aHomePageVO.setChnMedFee(paramsObj.getString("中成药费"));
        aHomePageVO.setChnHerbFee(paramsObj.getString("中草药费"));
        aHomePageVO.setBloodFee(paramsObj.getString("血费"));
        aHomePageVO.setAlbumenFee(paramsObj.getString("白蛋白类制品费"));
        aHomePageVO.setGlobulinFee(paramsObj.getString("球蛋白类制品费"));
        aHomePageVO.setBloodFactorFee(paramsObj.getString("凝血因子类制品费"));
        aHomePageVO.setCellFactorFee(paramsObj.getString("细胞因子类制品费"));
        aHomePageVO.setCheckMaterialFee(paramsObj.getString("检查用一次性医用材料费"));
        aHomePageVO.setTreatMaterialFee(paramsObj.getString("治疗用一次性医用材料费"));
        aHomePageVO.setOperationMaterialFee(paramsObj.getString("手术用一次性医用材料费"));
        aHomePageVO.setOtherTypeFee(paramsObj.getString("其他类其他费"));
        aHomePageVO.setSingleDiagManage(paramsObj.getString("单病种管理").trim());
        aHomePageVO.setClinicPathwayManage(paramsObj.getString("临床路径管理").trim());
        aHomePageVO.setIsOutpatientBehospital(paramsObj.getString("门诊与住院"));
        aHomePageVO.setIsLeaveBehospital(paramsObj.getString("入院与出院"));
        aHomePageVO.setIsOperationBeforeAfter(paramsObj.getString("术前与术后"));
        aHomePageVO.setIsClinicPathology(paramsObj.getString("临床与病理"));
        aHomePageVO.setIsRadiatePathology(paramsObj.getString("放射与病理"));
        //aHomePageVO.setRescueNum();
        //aHomePageVO.setRescueSuccessNum();
        //aHomePageVO.setIsAutoLeavehospital();
        aHomePageVO.setReturnToType(paramsObj.getString("转归情况").trim());

        List<Object> operationList = paramsObj.getJSONArray("手术信息");
//        if(operationList.size() > 0){
//            List<AHomeOperationVO> operationInfo = Lists.newLinkedList();
//            for (int i = 0; i < operationList.size(); i++) {
//                AHomeOperationVO aHomeOperationVO = new AHomeOperationVO();
//                aHomeOperationVO.setHomePageId(behospitalCode);
//                aHomeOperationVO.setHospitalId(hospitalId);
//                aHomeOperationVO.setOperationOrderNo(String.valueOf(i));
//                aHomeOperationVO.setOperationDate(((JSONArray) operationList).getJSONObject(i).getString("手术日期"));//待定2020-08-11
//                aHomeOperationVO.setOperationCode(((JSONArray) operationList).getJSONObject(i).getString("手术编码"));
//                aHomeOperationVO.setOperationDoctorId(((JSONArray) operationList).getJSONObject(i).getString("手术医生ID"));
//                aHomeOperationVO.setFirstAssistantId(((JSONArray) operationList).getJSONObject(i).getString("一助医生ID"));
//                aHomeOperationVO.setSecondAssistantId(((JSONArray) operationList).getJSONObject(i).getString("二助医生ID"));
//                aHomeOperationVO.setCutLevel(((JSONArray) operationList).getJSONObject(i).getString("切口等级"));
//                aHomeOperationVO.setHealingLevel(((JSONArray) operationList).getJSONObject(i).getString("愈合等级"));
//                aHomeOperationVO.setOperationName(((JSONArray) operationList).getJSONObject(i).getString("手术名称"));
//                aHomeOperationVO.setOperationLevel(((JSONArray) operationList).getJSONObject(i).getString("手术级别"));
//                aHomeOperationVO.setAnaesthesiaName(((JSONArray) operationList).getJSONObject(i).getString("麻醉方式"));
//                //aHomeOperationVO.setShamOperationName();
//
//                operationInfo.add(aHomeOperationVO);
//            }
//            aHomePageVO.setOperations(operationInfo);
//        }
        String sql = "SELECT * FROM AI_V_SENDHOMEPAGEING_SSQK t where t.homepageid = '" + behospitalCode + "'";
        aHomePageVO.setOperations(tzDBConn.getHomePageOperation(sql));
        List<Object> diagnoseList = paramsObj.getJSONArray("出院诊断");
        if (diagnoseList.size() > 0) {
            List<AHomeDiagnoseVO> leaveDiags = Lists.newLinkedList();
            for (int i = 0; i < operationList.size(); i++) {
                AHomeDiagnoseVO aHomeDiagnoseVO = new AHomeDiagnoseVO();
                aHomeDiagnoseVO.setHomePageId(behospitalCode);
                aHomeDiagnoseVO.setHospitalId(hospitalId);
                aHomeDiagnoseVO.setDiagnoseOrderNo(String.valueOf(i));//非空字段
                aHomeDiagnoseVO.setDiagnoseType(i == 0 ? "主要诊断" : "其他诊断");
                //aHomeDiagnoseVO.setDiagnoseTypeShort();
                aHomeDiagnoseVO.setDiagnoseName(((JSONArray) operationList).getJSONObject(i).getString("诊断名称"));
                aHomeDiagnoseVO.setBehospitalType(((JSONArray) operationList).getJSONObject(i).getString("入院情况"));
                aHomeDiagnoseVO.setLeaveHospitalType(((JSONArray) operationList).getJSONObject(i).getString("出院情况"));
                //aHomeDiagnoseVO.setPathologyDiagnose();
                aHomeDiagnoseVO.setIcdCode(((JSONArray) operationList).getJSONObject(i).getString("诊断编码"));
                leaveDiags.add(aHomeDiagnoseVO);
            }
            aHomePageVO.setLeaveDiags(leaveDiags);
        }
        aHomePageVOList.add(aHomePageVO);
        return aHomePageVOList;
    }


    public void execute(List<MedicalRecord> medicalRecordList) {
        try {
            List<MedicalRecord> addE = Lists.newLinkedList();
            List<MedicalRecord> updateE = Lists.newLinkedList();
            List<BehospitalInfo> behospitalInfoList = Lists.newLinkedList();
            List<QcAbnormal> qcAbnormalList = Lists.newLinkedList();
            if (medicalRecordList != null && medicalRecordList.size() > 0) {
                medicalRecordList.stream().forEach(s -> {
                    //初始化mode_id
                    Long modeId = initModeId(s);
                    if (modeId == Long.valueOf("0")) {
                        //新增类型到监测表中
                        QcAbnormal qcAbnormal = new QcAbnormal();
                        qcAbnormal.setHospitalId(s.getHospitalId());
                        qcAbnormal.setBehospitalCode(s.getBehospitalCode());
                        qcAbnormal.setType(1);
                        qcAbnormal.setDescription(s.getRecTitle());
                        qcAbnormal.setGmtCreate(new Date());
                        qcAbnormalList.add(qcAbnormal);
                    } else if (modeId == Long.valueOf("1")) {
                        BehospitalInfo behospitalInfo = behospitalInfoFacade.getOne(new QueryWrapper<BehospitalInfo>()
                                .eq("behospital_code", s.getBehospitalCode())
                                .eq("hospital_id", s.getHospitalId())
                                .eq("is_deleted", IsDeleteEnum.N), false);
                        if (behospitalInfo != null) {
                            //如果病人住院信息存在，更新对应的qc_type_id
                            Long qcTypeId = initQcTypeId(s, behospitalInfo);
                            behospitalInfo.setQcTypeId(qcTypeId);
                            behospitalInfoList.add(behospitalInfo);
                        }
                    }
                    s.setModeId(modeId);
                    //新增或修改
                    MedicalRecord mRecord = this.getOne(new QueryWrapper<MedicalRecord>()
                            .eq("rec_id", s.getRecId())
                            .eq("hospital_id", s.getHospitalId())
                            .eq("is_deleted", IsDeleteEnum.N)
                            .eq("behospital_code", s.getBehospitalCode()), false);
                    if (mRecord != null) {
                        s.setGmtModified(new Date());
                        updateE.add(s);
                    } else {
                        s.setGmtCreate(new Date());
                        addE.add(s);
                    }
                });
            }
            if (addE.size() > 0) {
                medicalRecordService.saveBatch(addE);
            }
            if (updateE.size() > 0) {
                medicalRecordService.updateBatchByKey(updateE);
            }
            if (qcAbnormalList.size() > 0) {
                qcAbnormalService.saveBatch(qcAbnormalList);
            }
            if (behospitalInfoList.size() > 0) {
                behospitalInfoFacade.updateBatchByKey(behospitalInfoList);
            }
            //aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息",JSON.toJSONString(medicalRecordList),"","操作正常!");
        } catch (Exception e) {
            aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息", "", JSON.toJSONString(medicalRecordList), "", e.getMessage());
        }
    }


    /**
     * 初始化质控类型ID
     *
     * @param medicalRecord
     * @return
     */
    private Long initQcTypeId(MedicalRecord medicalRecord, BehospitalInfo behospitalInfo) {
        Long qcTypeId = Long.valueOf("0");
        String behDeptId = behospitalInfo.getBehDeptId();
        String recTypeId = medicalRecord.getRecTypeId();
        if (recTypeId.contains("RJBL") || recTypeId.contains("24XSCRYJL")) {
            if (behDeptId.equals("52425")) {
                /**妇科(住)日间病历、24小时出入院记录的病历模板，映射妇科日间*/
                behDeptId = "52883";
                BasDeptInfo basDeptInfo = basDeptInfoFacade.getOne(new QueryWrapper<BasDeptInfo>()
                        .eq("dept_id", behDeptId)
                        .eq("hospital_id", behospitalInfo.getHospitalId())
                        .eq("is_deleted", IsDeleteEnum.N));
                behospitalInfo.setBehDeptId(behDeptId);
                behospitalInfo.setBehDeptName(basDeptInfo.getDeptName());
                behospitalInfo.setGmtModified(DateUtil.now());
            } else if (behDeptId.equals("51944")) {
                /**乳腺外科日间病历、24小时出入院记录的病历模板，映射乳腺外科日间日间*/
                behDeptId = "52923";
                BasDeptInfo basDeptInfo = basDeptInfoFacade.getOne(new QueryWrapper<BasDeptInfo>()
                        .eq("dept_id", behDeptId)
                        .eq("hospital_id", behospitalInfo.getHospitalId())
                        .eq("is_deleted", IsDeleteEnum.N));
                behospitalInfo.setBehDeptId(behDeptId);
                behospitalInfo.setBehDeptName(basDeptInfo.getDeptName());
                behospitalInfo.setGmtModified(DateUtil.now());
            } else if (behDeptId.equals("52424")) {
                /**儿科日间病历、24小时出入院记录的病历模板，映射儿科日间*/
                behDeptId = "52903";
                BasDeptInfo basDeptInfo = basDeptInfoFacade.getOne(new QueryWrapper<BasDeptInfo>()
                        .eq("dept_id", behDeptId)
                        .eq("hospital_id", behospitalInfo.getHospitalId())
                        .eq("is_deleted", IsDeleteEnum.N));
                behospitalInfo.setBehDeptId(behDeptId);
                behospitalInfo.setBehDeptName(basDeptInfo.getDeptName());
                behospitalInfo.setGmtModified(DateUtil.now());
            }
        }
        List<QcType> qcTypeList = qcTypeFacade.list(new QueryWrapper<QcType>()
                .eq("beh_dept_id", behDeptId)
                .eq("hospital_id", behospitalInfo.getHospitalId())
                .eq("is_deleted", IsDeleteEnum.N));
        if (medicalRecord != null) {
            if (qcTypeList.size() == 0) {
                QcType qcType = qcTypeFacade.getOne(new QueryWrapper<QcType>()
                        .eq("default_module", 1)
                        .eq("hospital_id", behospitalInfo.getHospitalId())
                        .eq("is_deleted", IsDeleteEnum.N));
                qcTypeId = qcType.getId();
            } else if (qcTypeList.size() == 1) {
                qcTypeId = qcTypeList.get(0).getId();
            } else {
                QcType qcType = new QcType();
                qcTypeList.forEach(ss -> {
                    if (ss.getSex().equals(behospitalInfo.getSex())) {
                        qcType.setId(ss.getId());
                    }
                });
                qcTypeId = qcType.getId();
            }
//            }
        }
        return qcTypeId;
    }

    /**
     * 初始化模型ID
     *
     * @param medicalRecord
     * @return
     */
    private Long initModeId(MedicalRecord medicalRecord) {
        Long modeId = Long.valueOf("0");
        try {
            QueryWrapper<ModelHospital> wrapper = new QueryWrapper<>();
            wrapper.eq("hospital_id", medicalRecord.getHospitalId());
            wrapper.eq("hospital_model_name", medicalRecord.getRecTitle());
            ModelHospital mode = modelHospitalFacade.getOne(wrapper, false);
            String recTitle = medicalRecord.getRecTitle();
            if (mode != null) {
                modeId = mode.getStandModelId();
            } else {
                modeId = Long.valueOf("0");
                ModelHospital modelHospital = new ModelHospital();
                modelHospital.setHospitalId(5L);
                modelHospital.setHospitalModelName(medicalRecord.getRecTitle());
                if (recTitle.contains("查房")) {
                    modeId = 4L;
                    modelHospital.setStandModelId(4L);
                    modelHospital.setStandModelName("查房记录");
                } else if (recTitle.contains("手术知情同意书")) {
                    modeId = 16L;
                    modelHospital.setStandModelId(16L);
                    modelHospital.setStandModelName("知情同意书");
                } else if (recTitle.contains("有创") && recTitle.contains("知情同意书")) {
                    modeId = 59L;
                    modelHospital.setHospitalId(59L);
                    modelHospital.setHospitalModelName(recTitle);
                }
                modelHospitalFacade.save(modelHospital);
            }
            //aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息-初始化modeId",JSON.toJSONString(medicalRecord),modeId.toString(),"操作成功!");
            return modeId;
        } catch (Exception e) {
            aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息-初始化modeId", medicalRecord.getRecId(), JSON.toJSONString(medicalRecord), "", e.getMessage());
            return modeId;
        }

    }

    public RespDTO deleteFlag(ADeleteFlagVO aDeleteFlagVO) {
        try {
            //验证数据是否存在
            if (StringUtil.isEmpty(aDeleteFlagVO.getRecId())) {
                return RespDTO.onError("请输入文书序号!");
            } else if (aDeleteFlagVO.getHospitalId() == null) {
                return RespDTO.onError("请输入医院编码!");
            } else if (StringUtil.isEmpty(aDeleteFlagVO.getBehospitalCode())) {
                return RespDTO.onError("请输入病人住院编码!");
            } else {
                UpdateWrapper<MedicalRecord> updateWrapper = new UpdateWrapper<>();
                updateWrapper.eq("rec_id", aDeleteFlagVO.getRecId())
                        .eq("hospital_id", aDeleteFlagVO.getHospitalId())
                        .eq("behospital_code", aDeleteFlagVO.getBehospitalCode())
                        .eq("is_deleted", IsDeleteEnum.N)
                        .set("is_deleted", IsDeleteEnum.Y)
                        .set("gmt_modified", DateUtil.now());
                Boolean flag = update(new MedicalRecord(), updateWrapper);
                if (flag) {
                    UpdateWrapper<MedicalRecordContent> updateWrapperContent = new UpdateWrapper<>();
                    updateWrapperContent.eq("rec_id", aDeleteFlagVO.getRecId())
                            .eq("hospital_id", aDeleteFlagVO.getHospitalId())
                            .eq("is_deleted", IsDeleteEnum.N)
                            .set("is_deleted", IsDeleteEnum.Y)
                            .set("gmt_modified", DateUtil.now());

                    Boolean flagContent = aMedicalRecordContentFacade.update(new MedicalRecordContent(), updateWrapperContent);
                    //aMedAbnormalInfoFacade.saveAbnormalInfo("文书内容-删除",JSON.toJSONString(aDeleteFlagVO),JSON.toJSONString(RespDTO.onSuc(flagContent)),"操作成功!");
                }
                //aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息-删除",JSON.toJSONString(aDeleteFlagVO),JSON.toJSONString(RespDTO.onSuc(flag)),"操作成功!");
                return RespDTO.onSuc(flag);
            }
        } catch (Exception e) {
            aMedAbnormalInfoFacade.saveAbnormalInfo("文书-删除", aDeleteFlagVO.getRecId(), JSON.toJSONString(aDeleteFlagVO), "", e.getMessage());
            return RespDTO.onError(e.getMessage());
        }
    }

    public String coverValue(String field, String type) {
        Pattern p = Pattern.compile("[\u4e00-\u9fa5]");
        Matcher m = p.matcher(field);
        if (type.equals("ZG")) {
            /**职工*/
            return m.find() ? field : tzDBConn.getDoctorName(field);
        } else if (type.equals("KS")) {
            /**科室*/
            return m.find() ? field : tzDBConn.getDeptName(field);
        } else if (type.equals("MZ")) {
            /**民族*/
            return m.find() ? field : FamousFamilyEnum.getName(field);
        }
        return "";
    }
}